Learn R Programming

Rfuzzycoco (version 0.1.0)

compute_optimal_quantile_fuzzy_set_positions: computes the optimal fuzzy set positions based on the distribution of the data

Description

computes the optimal fuzzy set positions based on the distribution of the data

Usage

compute_optimal_quantile_fuzzy_set_positions(df, nb_sets)

Value

a list, named after the df column names, holding the vector of positions per variable

Arguments

df

the data as a data frame

nb_sets

the number of fuzzy sets

Examples

Run this code
pos <- compute_optimal_quantile_fuzzy_set_positions(mtcars, 3)
print("position for 2nd fuzzy set for qsec var", pos$qsec[[2]])

Run the code above in your browser using DataLab