Learn R Programming

Rfuzzycoco (version 0.1.0)

fit_to_df: a one-row overview of a fuzzy system with the usage of variables, the fitness, number of generations and optionally a metric

Description

a one-row overview of a fuzzy system with the usage of variables, the fitness, number of generations and optionally a metric

Usage

fit_to_df(fit, metric = NULL)

Value

a one-row data frame

Arguments

fit

a fit object, as returned by [fit.

metric

an optional metric name to report (e.g. rmse)

See Also

Other fit_utils: fs_rules_to_df(), fs_used_vars_to_df()

Examples

Run this code
model <- fuzzycoco("regression", example_mtcars()$params, seed = 123)
df <- mtcars[c("mpg", "hp", "wt", "qsec")]
fit <- fit(model, qsec ~ ., df, seed = 456, max_generations = 10, progress = FALSE)

print(fit_to_df(fit))

Run the code above in your browser using DataLab