Learn R Programming

Rfuzzycoco (version 0.1.0)

fs_used_vars_to_df: extract the usage of the variables by a fuzzy system

Description

extract the usage of the variables by a fuzzy system

Usage

fs_used_vars_to_df(fuzzy_system_desc)

Value

a one-row data frame, in columns the input and output variables, with TRUE iff the variable is used.

Arguments

fuzzy_system_desc

a fuzzy system description as a named list

See Also

Other fit_utils: fit_to_df(), fs_rules_to_df()

Examples

Run this code
model <- fuzzycoco("regression", example_mtcars()$params, seed = 123)
df <- mtcars[c("mpg", "hp", "wt", "qsec")]
fit <- fit(model, qsec ~ ., df, seed = 456, max_generations = 10, progress = FALSE)

print(fs_rules_to_df(fit$fuzzy_system))

Run the code above in your browser using DataLab