Learn R Programming

Rfuzzycoco (version 0.1.0)

fuzzy_coco_parsnip: parsnip model function

Description

parsnip model function

Usage

fuzzy_coco_parsnip(
  mode = "unknown",
  params,
  engine = FUZZY_COCO_HYBRID_ENGINE,
  seed = sample.int(10^5, 1),
  verbose = FALSE
)

Value

a parsnip model

Arguments

mode

the type of model, either classification or regression

params

fuzzy coco parameters, as a recursive named list, cf params()

engine

the fuzzy coco fit engine to use, one of rcpp and hybrid

seed

the RNG seed to use (to fit the model)

verbose

whether to be verbose

Examples

Run this code
spec <- fuzzy_coco_parsnip("regression",  params = example_mtcars()$params, seed = 123)
fit <- spec |> parsnip::set_engine("hybrid") |> parsnip::fit(qsec ~ ., data = example_mtcars()$data)

Run the code above in your browser using DataLab