powered by
computes the optimal fuzzy set positions based on the distribution of the data
compute_optimal_quantile_fuzzy_set_positions(df, nb_sets)
a list, named after the df column names, holding the vector of positions per variable
the data as a data frame
the number of fuzzy sets
pos <- compute_optimal_quantile_fuzzy_set_positions(mtcars, 3) print("position for 2nd fuzzy set for qsec var", pos$qsec[[2]])
Run the code above in your browser using DataLab