powered by
parsnip model function
fuzzy_coco_parsnip( mode = "unknown", params, engine = FUZZY_COCO_HYBRID_ENGINE, seed = sample.int(10^5, 1), verbose = FALSE )
a parsnip model
the type of model, either classification or regression
fuzzy coco parameters, as a recursive named list, cf params()
params()
the fuzzy coco fit engine to use, one of rcpp and hybrid
the RNG seed to use (to fit the model)
whether to be verbose
spec <- fuzzy_coco_parsnip("regression", params = example_mtcars()$params, seed = 123) fit <- spec |> parsnip::set_engine("hybrid") |> parsnip::fit(qsec ~ ., data = example_mtcars()$data)
Run the code above in your browser using DataLab