fuzzycoco_fit_df_hybrid: lowest-level implementation of the fitting of a fuzzy coco model using the hybrid engine
Description
lowest-level implementation of the fitting of a fuzzy coco model using the hybrid engine
Usage
fuzzycoco_fit_df_hybrid(
model,
x,
y,
until = stop_engine_on_first_of(max_generations =
model$params$global_params$max_generations, max_fitness =
model$params$global_params$max_fitness),
verbose = model$verbose,
progress = TRUE
)
Value
a named list as a fuzzy_coco fit object
Arguments
model
a Fuzzy Coco model as a fuzzy_coco object
x
the input variables data (usually to fit) as a dataframe
y
the output variables data (usually to fit) as a dataframe
until
function that takes an engine and returns TRUE if and only if the evolution must stop.
It is a way for the user to customize the stop conditions of the algorithm.
verbose
whether to be verbose
progress
whether to display the computation progress (using progressr, if available)